## Version 0.11.5

This release includes updates to project dependencies and enhancements to the project's package management.

### New Features

- Updated project dependencies and refreshed the lockfile to ensure compatibility and security. (0cf734) (Eric Ma)
- Added 'sentence-transformers' to the 'rag' extra dependencies, enhancing the project's NLP capabilities. (0cf734) (Eric Ma)

### Bug Fixes

- None

### Deprecations

- None
